import { RoleType } from '@/constants/enumerate';

export interface LoginData {
  account: string;
  password: string;
}

// 登录名	名称	来源	角色	状态	关联账号
export interface UserItem {
  id: number;
  // 登录名
  loginName: string;
  // 名称
  name: string;
  // 工号 (可选)
  empno: string;
  // 来源 (例如：内部用户)
  source: string;
  // 角色 (例如：学校管理员, 扫描员)
  role: RoleType;
  // 状态 (启用/禁用)
  enable: boolean;
  // 关联账号
  relatedAccount: string;
  schoolId: number;
  lastLoginIp: string;
  description: string;
}
export type UserListPageRes = PageResult<UserItem>;

export interface UserListFilter {
  name?: string; // 按名称搜索
  loginName?: string; // 按登录名搜索
  enable: boolean; // 按状态筛选
  role?: RoleType; // 按角色筛选
  source?: string; // 按来源筛选
}
export type UserListPageParam = PageParams<UserListFilter>;

export interface UserUpdateParam {
  id?: number;
  // 登录名
  loginName: string;
  // 名称
  name: string;
  // 工号 (可选)
  empno: string;
  // 状态 (启用/禁用)
  enable: boolean;
  // 角色 (例如：学校管理员, 扫描员)
  role: RoleType;
  password: string;
}

export interface ResetPasswordParam {
  ids: number[];
  password: string; // 如果不传，后端可能会生成随机密码
}
export interface EnableUserParam {
  ids: number[];
  enabled: boolean;
}

export interface UpdatePwdData {
  // id: number;
  // oldPassword: string;
  password: string;
}

export interface BatchCreateUserParam {
  examId: number;
  // 角色
  role: RoleType;
  // 命名规则
  prefix: string;
  // 每分组账号数
  number: number;
  // 是否随机密码
  random: boolean;
  // 密码
  password?: string;
  // 科目
  subjectCodeString: string;
}
